@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2023  Jean-Philippe Lang
+# Copyright (C) 2006-  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class TimelogControllerTest < Redmine::ControllerTest
   fixtures :projects, :enabled_modules, :roles, :members,
@@ -89,7 +89,20 @@ class TimelogControllerTest < Redmine::ControllerTest
     assert_response 403
   end
 
-  def test_new_should_select_default_activity
+  def test_new_should_select_default_role_activity
+    developer = Role.find(2)
+    developer.default_time_entry_activity_id = 9
+    developer.save!
+
+    @request.session[:user_id] = 3
+    get :new, :params => {:project_id => 1}
+    assert_response :success
+    assert_select 'select[name=?]', 'time_entry[activity_id]' do
+      assert_select 'option[selected=selected]', :text => 'Design'
+    end
+  end
+
+  def test_new_should_select_default_global_activity_for_user_roles_without_default_activities
     @request.session[:user_id] = 3
     get :new, :params => {:project_id => 1}
     assert_response :success
@@ -1164,7 +1177,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     }
     assert_response :success
     assert_equal(
-      [t2, t1, t3].map(&:id).map(&:to_s),
+      [t2, t1, t3].map {|t| t.id.to_s},
       css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
     )
     get(
@@ -1179,7 +1192,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     )
     assert_response :success
     assert_equal(
-      [t3, t1, t2].map(&:id).map(&:to_s),
+      [t3, t1, t2].map {|t| t.id.to_s},
       css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
     )
   end
@@ -1205,7 +1218,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     ].each do |sort_criteria, expected|
       get :index, :params => params.dup.merge(sort_criteria)
       assert_response :success
-      expected_ids = expected.map(&:id).map(&:to_s)
+      expected_ids = expected.map {|t| t.id.to_s}
       actual_ids = css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
       assert_equal expected_ids, actual_ids
     end
@@ -1242,7 +1255,20 @@ class TimelogControllerTest < Redmine::ControllerTest
       }
     )
     assert_response :success
-    assert_equal [entry].map(&:id).map(&:to_s), css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
+    assert_equal [entry.id.to_s], css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
+  end
+
+  def text_index_with_issue_subject_filter
+    get(
+      :index,
+      :params => {
+        :f => ['issue.subject'],
+        :op => {'issue.subject' => '~'},
+        :v => {'issue.subject' => ['"updating a recipe"']}
+      }
+    )
+    assert_response :success
+    assert_equal [3], css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
   end
 
   def test_index_with_project_status_filter
@@ -1308,7 +1334,7 @@ class TimelogControllerTest < Redmine::ControllerTest
       :v => {'issue.tracker_id' => ['2']}
     }
     assert_response :success
-    assert_equal [entry].map(&:id).map(&:to_s), css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
+    assert_equal [entry.id.to_s], css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
   end
 
   def test_index_with_issue_tracker_column
@@ -1361,6 +1387,52 @@ class TimelogControllerTest < Redmine::ControllerTest
     assert_select 'td.issue-category', :text => 'Printing'
   end
 
+  def test_index_with_issue_parent_filter
+    issue1 = Issue.generate!(project_id: 'ecookbook', parent_id: 2)
+    entry1 = TimeEntry.generate!(issue: issue1, hours: 2.5)
+    issue2 = Issue.generate!(project_id: 'ecookbook', parent_id: 5)
+    entry2 = TimeEntry.generate!(issue: issue2, hours: 5.0)
+
+    get :index, params: {
+      project_id: 'ecookbook',
+      f: ['issue.parent_id'],
+      op: {'issue.parent_id' => '='},
+      v: {'issue.parent_id' => ['2,5']}
+    }
+    assert_response :success
+    assert_equal [entry1.id, entry2.id].sort, css_select('input[name="ids[]"]').map {|e| e.attr(:value).to_i}.sort
+  end
+
+  def test_index_with_issue_parent_column
+    issue = Issue.generate!(project_id: 'ecookbook', parent_id: 2)
+    entry = TimeEntry.generate!(issue: issue, hours: 2.5)
+
+    get :index, params: {
+      project_id: 'ecookbook',
+      c: %w(project spent_on issue comments hours issue.parent)
+    }
+
+    assert_response :success
+    assert_select 'td.issue-parent', text: "#{issue.parent.tracker} ##{issue.parent.id}"
+  end
+
+  def test_index_with_issue_parent_sort
+    issue1 = Issue.generate!(project_id: 'ecookbook', parent_id: 2)
+    entry1 = TimeEntry.generate!(issue: issue1, hours: 2.5)
+    issue2 = Issue.generate!(project_id: 'ecookbook', parent_id: 5)
+    entry2 = TimeEntry.generate!(issue: issue2, hours: 5.0)
+
+    get :index, :params => {
+      :c => ["hours", 'issue.parent'],
+      :sort => 'issue.parent'
+    }
+    assert_response :success
+
+    # Make sure that values are properly sorted
+    values = css_select("td.issue-parent").map(&:text).reject(&:blank?)
+    assert_equal ["#{issue1.parent.tracker} ##{issue1.parent.id}", "#{issue2.parent.tracker} ##{issue2.parent.id}"].sort, values.sort
+  end
+
   def test_index_with_issue_fixed_version_column
     issue = Issue.find(1)
     issue.fixed_version = Version.find(3)
@@ -1446,7 +1518,7 @@ class TimelogControllerTest < Redmine::ControllerTest
     }
     assert_response :success
     assert_equal(
-      [entry].map(&:id).map(&:to_s),
+      [entry.id.to_s],
       css_select('input[name="ids[]"]').map {|e| e.attr(:value)}
     )
   end
@@ -1677,6 +1749,18 @@ class TimelogControllerTest < Redmine::ControllerTest
     end
   end
 
+  def test_index_csv_filename_query_name_param
+    get :index, :params => {:format => 'csv'}
+    assert_response :success
+    assert_match /timelog.csv/, @response.headers['Content-Disposition']
+  end
+
+  def test_index_csv_filename_with_query_name_param
+    get :index, :params => {:query_name => 'My Query Name', :format => 'csv'}
+    assert_response :success
+    assert_match /my_query_name\.csv/, @response.headers['Content-Disposition']
+  end
+
   def test_index_csv_should_fill_issue_column_with_tracker_id_and_subject
     issue = Issue.find(1)
     entry = TimeEntry.generate!(:issue => issue, :comments => "Issue column content test")
